@@ -117,6 +117,9 @@ class Formula:
 
         """
 
+        if formula == 'hv':
+            formula == 'hν'
+
         self.formula = formula
         self.parse_formula(formula)
 
@@ -169,6 +172,16 @@ class Formula:
     def parse_formula(self, formula):
         """Parse the string formula into a Formula object."""
 
+        if formula == 'D-':
+            # This is a not-ideal way to deal with the fact that D- breaks
+            # the parser due to a clash with the D- prefix.
+            self.parse_formula('D-1')
+            return
+
+        if any(s in formula for s in ('++', '--', '+-', '-+')):
+            raise FormulaParseError('Invalid formula syntax: {}'
+                                                    .format(formula))
+
         self.atoms = set()
 
         # We make a particular exception for various special cases, including
@@ -386,6 +399,43 @@ class Formula:
         atom_strs.sort()
         return atom_strs
 
+
+    def _stoichiometric_formula_hill(self):
+        """Return a list of atoms/isotopes and their stoichiometries.
+
+        The returned list is sorted in "Hill notation": first carbon, then
+        hydrogen, then all other chemical elements in alphabetical order.
+        If the species contains H but no C, all elements are listed in
+        alphabetical order, including hydrogen.
+
+        """
+
+        CH_strs = []
+        atom_strs = []
+        contains_C = False
+        for atom in sorted(self.atoms, key=lambda e: (e.Z, e.mass)):
+            if atom.is_isotope:
+                symbol = '({})'.format(atom.symbol)
+            else:
+                symbol = atom.symbol
+            if symbol == 'C':
+                CH_strs.insert(0, self._get_symbol_stoich('C',
+                                        self.atom_stoich['C']))
+                contains_C = True
+            elif symbol == 'H':
+                CH_strs.insert(1, self._get_symbol_stoich('H',
+                                        self.atom_stoich['H']))
+            else:
+                atom_strs.append(self._get_symbol_stoich(symbol,
+                            self.atom_stoich[atom.symbol]))
+        
+        if not contains_C:
+            atom_strs = CH_strs + atom_strs
+            CH_strs = []
+        atom_strs.sort()
+        return CH_strs + atom_strs
+
+
     def stoichiometric_formula(self, fmt='atomic number'):
         """
         Return a string representation of the stoichiometric formula
@@ -403,10 +453,11 @@ class Formula:
             return 'e-'
         if self.formula in ('hv', 'hν'):
             # Special case for the photon
+            self.formula = 'hν'
             return 'hν'
 
         fmt = fmt.lower()
-        if fmt not in ('atomic number', 'alphabetical'):
+        if fmt not in ('atomic number', 'alphabetical', 'hill'):
             raise FormulaError('Unsupported format for stoichiometric'
                     ' formula output: {}'.format(fmt))
 
@@ -414,6 +465,8 @@ class Formula:
             atom_strs = self._stoichiometric_formula_atomic_number()
         elif fmt == 'alphabetical':
             atom_strs = self._stoichiometric_formula_alphabetical()
+        elif fmt == 'hill':
+            atom_strs = self._stoichiometric_formula_hill()
 
         # finally, add on the charge string, e.g. '', '-', '+2', ...
         atom_strs.append(self._get_charge_string())
