@@ -33,6 +33,21 @@ class KeyValuePairTest(unittest.TestCase):
         self.assertNotEqual(kv1, kv3)
         self.assertNotEqual(kv2, kv4)
 
+    def test_key_value_pair_repr(self):
+        kv1 = KeyValuePair('n=2')
+        kv2 = KeyValuePair('n =2')
+        kv3 = KeyValuePair('n= 2')
+        kv4 = KeyValuePair('n = 2')
+        kv5 = KeyValuePair('n  = 2')
+        self.assertTrue(repr(kv1) == repr(kv2) == repr(kv3) == repr(kv4)
+                     == repr(kv5) == 'n=2')
+
+    def test_html_escaping(self):
+        kv1 = KeyValuePair('S="5<n<9"')
+        self.assertEqual(repr(kv1), 'S="5<n<9"')
+        self.assertEqual(kv1.html, 'S=&quot;5&lt;n&lt;9&quot;')
+
+
 if __name__ == '__main__':
     unittest.main()
 
